#!/bin/bash

# This script creates encrypted directories running Ubuntu Linux using EncFS and gnome-encfs.
# All necessary programs will be downloaded and installed automatically.
#
# Dieses Skript erstellt unter Ubuntu Linux verschlüsselte Verzeichnisse mit EncFS und gnome-encfs.
# Alle benötigten Programme werden automatisch heruntergeladen und installiert.
#
#      2010 by JaiBee, http://www.321tux.de
#      License: Creative Commons BY-NC-SA 3.0 (http://creativecommons.org/licenses/by-nc-sa/3.0/)
#
# References:
# http://bitbucket.org/obensonne/gnome-encfs/overview/
# http://pragmattica.wordpress.com/2009/05/10/encrypting-your-dropbox-seamlessly-and-automatically/

# Standard
ENCRYPTED="$HOME/.Encrypted"	# Verschlüsselt
DECRYPTED="$HOME/Decrypted"		# Entschlüsselt

# Dropbox
DROPBOX_ENCRYPTED="$HOME/Dropbox/Encrypted"
DROPBOX_DECRYPTED="$HOME/Dropbox-Decrypted"

# Ubuntu One
UONE_ENCRYPTED="$HOME/Ubuntu One/Encrypted"
UONE_DECRYPTED="$HOME/Ubuntu One Decrypted"

# Download-URL für gnome-encfs
DL_GNOME_ENCFS="http://bitbucket.org/obensonne/gnome-encfs/get/tip.tar.gz"

# - - - - - - - - - - - - - - - - START - - - - - - - - - - - - - - - - #

clear
echo "Was möchten Sie tun?"                   # What do you want to do?
echo " 1 Verschlüsseltes Verzeichnis anlegen" # Create encrypted directory
echo "     ($ENCRYPTED)"
echo " 2 Verschlüsseltes Verzeichnis für Dropbox anlegen"
echo "     ($DROPBOX_ENCRYPTED)"
echo " 3 Verschlüsseltes Verzeichnis für Ubuntu One anlegen"
echo "     ($UONE_ENCRYPTED)"
echo " 4 Verzeichnisse selbst festlegen"      # Configure own directories
read -p "> Bitte geben Sie die entsprechende Nummer ein [1,2,3,4] " TODO

case $TODO in
	1) ;;
	2) ENCRYPTED="$DROPBOX_ENCRYPTED"; DECRYPTED="$DROPBOX_DECRYPTED" ;;
	3) ENCRYPTED="$UONE_ENCRYPTED";    DECRYPTED="$UONE_DECRYPTED" ;;
	4) read -p "> verschlüsseltes Verzeichnis: " ENCRYPTED; read -p "> entschlüsseltes Verzeichnis: " DECRYPTED 
		# Benutzereingabe überprüfen
		if [[ ! "$ENCRYPTED" =~ ^\/ || ! "$DECRYPTED" =~ ^\/ ]]; then
			echo "ERROR: Relative Pfadangaben sind nicht erlaubt"; exit 1
		elif [ "$ENCRYPTED" == "$DECRYPTED" ]; then
			echo "ERROR: Die Verzeichnisse müssen unterschiedlich sein"; exit 1
		fi ;;
	?) echo "ERROR: Ungülige Auswahl"; exit 1 ;;
	*) echo "ERROR: Es wurde nichts ausgewählt"; exit 1;;
esac

echo
echo "Sie haben gewählt:"   # You have chosen
echo "- verschlüsseltes Verzeichnis: $ENCRYPTED"
echo "- entschlüsseltes Verzeichnis: $DECRYPTED"
read -p "> Fortfahren? [Enter]"
echo

# EncFS installieren?
if ! which encfs > /dev/null 2>&1; then
	echo "- EncFS wird installiert"
	sudo apt-get install encfs
	echo
else
	echo "- EncFS ist bereits installiert"
fi

# EncFS konfigurieren?
if encfsctl "$ENCRYPTED" > /dev/null 2>&1 && [ -d $DECRYPTED ]; then
	echo "- EncFS ist bereits konfiguriert"
else
	echo "- EncFS muss für $ENCRYPTED zunächst konfiguriert werden"  # Need to configure EncFS
	echo "> ein zweites Fenster wird sich öffnen,"
	read -p "  in dem die notwendigen Schritte angezeigt werden [Enter]"
	xterm -hold -geometry 90x20 -title "Anleitung für EncFS-Konfiguration" -e 'echo "- ‘y’ eingeben, um '"$ENCRYPTED"' anzulegen
- ggf. ‘y’ eingeben, um '"$DECRYPTED"' anzulegen
- ggf. ‘x’ eingeben, um den Experten-Modus zu wählen
- ‘1’ für den AES Verschlüssellungsalgorithmus eingeben
- ‘256’ für die Schlüssellänge eingeben
- ‘1024’ für die Dateisystem-Blockgröße eingeben
- ‘1′ für die Verschlüsselung der Dateinamen eingeben
- ‘y’ bei ‘filename initialization vector chaining’ eingeben
- ‘n’ bei ‘per-file initialization vectors’ eingeben
- ‘n’ bei ‘block authentication code headers’ eingeben
- ‘y’ bei ‘file-hole pass-through’ eingeben
- Passwort für das verschlüsselte Dateisystem wiederholt eingeben

Quelle:
http://pragmattica.wordpress.com/2009/05/10/encrypting-your-dropbox-seamlessly-and-automatically/."' & \
	encfs "$ENCRYPTED" "$DECRYPTED"		# EncFS-Dateisystem erstellen

	# Xterm beenden (anhand Prozessnummer)
	kill $(ps -fC xterm | grep EncFS-Konf | tr -s [:blank:] " " | cut -d " " -f2)
fi

# gnome-encfs installieren?
if [ -f /usr/local/bin/gnome-encfs ]; then
	echo "- gnome-encfs ist bereits installiert"
else
	echo "- gnome-encfs wird heruntergeladen und installiert"
	# gnome-encfs herunterladen und entpacken
	wget -q -O - "$DL_GNOME_ENCFS" | tar xvzf - > /dev/null || exit 1

	# in das Verzeichnis von gnome-encfs wechseln
	cd gnome-encfs

	# gnome-encfs installieren
	sudo install gnome-encfs /usr/local/bin || exit 1
fi

# gnome-encfs konfigurieren?
if gnome-encfs -l | grep "$ENCRYPTED" > /dev/null 2>&1 ; then
	echo "- gnome-encfs ist bereits konfiguriert"
else
	echo "- gnome-encfs muss für $ENCRYPTED konfiguriert werden:"
	gnome-encfs --amount=y -a "$ENCRYPTED" "$DECRYPTED"
fi

# Noch nicht eingebunden?
if ! mount | grep "$DECRYPTED" > /dev/null 2>&1; then
	gnome-encfs -m "$ENCRYPTED"
fi

echo
echo "FERTIG!" # Finished
echo "- Sie können Dateien nun in $DECRYPTED ablegen."
echo "- Diese werden dann verschlüsselt in $ENCRYPTED gespeichert."
